package #
  Path::Extended::Test;

use strict;
use warnings;
use base qw( Path::Extended );

1;
